/***********************************************************************
 * Module:  BaseJavaScriptInterface.java
 * Author:  allen
 * Purpose: Defines the Class BaseJavaScriptInterface
 ***********************************************************************/

package com.hexin.android.webviewjsinterface;

import java.lang.ref.SoftReference;

import org.json.JSONException;
import org.json.JSONObject;

import android.webkit.WebView;

/** @pdOid b74d7a5b-8081-426e-9d18-aa09730e0726 */
public class BaseJavaScriptInterface implements JavaScriptInterface {
	private SoftReference<WebView> mWebViewRef = null;
	private String mCallBackId = null;
	private String mHandlerName = null;


	/** @pdOid 69809fa5-7ec0-4531-b77c-5ba95b6705b4 */
	public void onInterfaceRemoved() {
        if(mWebViewRef != null){
            synchronized (mWebViewRef) {
                mWebViewRef.clear();
                mWebViewRef = null;
            }
        }
		mCallBackId = null;
	}

	@Override
	public void onEventAction(WebView webview, String callbackId, String message) {
		// TODO Auto-generated method stub
		if (webview == null || callbackId == null) {
			return;
		}
		mWebViewRef = new SoftReference<WebView>(webview);
		this.mCallBackId = callbackId;
	}

    @Override
    public void onActionCallBack(Object object) {

        if (mWebViewRef == null || mWebViewRef.get() == null) {
            return;
        }
        synchronized (mWebViewRef) {
            
            // 组装JSON
            // responseId ,responseData
            JSONObject jsonObj = new JSONObject();
            String jsonString = null;
            try {
                jsonObj.put("responseId", mCallBackId);
                jsonObj.put("handlerName", mHandlerName);
                jsonObj.put("responseData", object);
                jsonString = jsonObj.toString();
            } catch (JSONException e) {
                // TODO Auto-generated catch block
                e.printStackTrace();
            }
            // callback
            if (jsonString == null || mWebViewRef == null || mWebViewRef.get() == null) {
                return;
            }
            final String jString = jsonString;
            final WebView view =  mWebViewRef.get();
            if(view!=null){
                view.loadUrl(
                        "javascript:window.WebViewJavascriptBridge._handleMessageFromObjC('"
                                + jString + "')");
            }
        }
    
    }

    @Override
    public void onEventAction(WebView webview, String callbackId, String handlerName, String message) {
        if (webview == null) {
            return;
        }
        mWebViewRef = new SoftReference<WebView>(webview);
        this.mCallBackId = callbackId;
        this.mHandlerName = handlerName;
    }

}